PROC SQL;			/* JOIN WITH CLIMATE DATA       */
   CREATE TABLE WORK.QUERY_FOR_MAINMAIN AS 
   SELECT T1.'UFOSIGHTINGLOCATION 2'N AS LOCATION, 
          T1.UFOSIGHTINGDATE, 
		  SUBSTR(T1.UFOSIGHTINGDATE,3,3) AS MON,
          T2.STATE,
		  T2.'AVG DAILY MAX AIR TEMPERATURE (F'N AS TEMPMAX, 
          T2.'AVG DAILY MIN AIR TEMPERATURE (F'N AS TEMPMIN
      FROM WORK.MAINMAIN T1
           LEFT JOIN WORK.MAINEXCEL T2 ON (T1.UFOSIGHTINGDATE = T2.'MONTH DAY, YEAR'N) AND (T1.'UFOSIGHTINGLOCATION 2'N 
          = T2.STATECODE)
WHERE STATE IS NOT NULL;

CREATE TABLE WORK.FINAL AS		/* CALCULATE AVG MAX AND MIN TEMP   */
SELECT  STATE,
		MON,
		COUNT(*) AS NUM,
		AVG(TEMPMAX) AS MAXTEMP,
		AVG(TEMPMIN) AS MINTEMP
FROM WORK.QUERY_FOR_MAINMAIN
GROUP BY STATE, MON;

CREATE TABLE WORK.FINALSTATE AS	/* GET TEMPERATURE BY STATE       */
SELECT  STATE,
		MIN(MAXTEMP) AS TEMPMAXIMUM,
		MAX(MINTEMP) AS TEMPMINIMUM
FROM WORK.FINAL
GROUP BY STATE;

QUIT;

PROC SQL;
   CREATE TABLE WORK.FILTER_FOR_FINALFINAL1_SAS7BDAT AS 
   SELECT T1.STATECOD, 
          T1.MON, 
          T1.NUM, 
          T1.MAXTEMP, 
          T1.MINTEMP, 
          T1.STATE, 
      FROM EC100044.FINALFINAL T1
      ORDER BY T1.STATECODE;
QUIT;
PROC SQL;				/* GET STATE CODE NUMBER FROM MAPS       */
   CREATE TABLE WORK.FILTER_FOR_US AS 
   SELECT DISTINCT T1.STATE, 
          T1.STATECODE
      FROM MAPSGFK.US T1;
QUIT;
PROC SQL;				/* PREPARE DATA*/
   CREATE TABLE WORK.FILTER_FOR_FINALFINAL_SAS7BDAT AS 
   SELECT T1.STATECOD, 
          T1.MON, 
          T1.NUM, 
          T1.MAXTEMP, 
          T1.MINTEMP, 
          T1.STATE AS STATECODET1,
		  T2.STATECODE AS STATECODET2,
		  T2.STATE AS STATE
      FROM EC100044.FINALFINAL T1, WORK.FILTER_FOR_US T2
	  WHERE T1.STATE=T2.STATECODE
      ORDER BY T1.STATE;
QUIT;

PROC SQL; 		/* PREPARE FINAL DATASET       */
   CREATE TABLE WORK.FILTER_FOR_FINALFINAL_SAS7BDAT AS 
   SELECT SUM(T1.NUM) AS NUMOFSIGHTINGS, 
          MAX(T1.MAXTEMP) AS MAXTEMP, 
          MIN(T1.MINTEMP) AS MINTEMP, 
          T1.STATE
         FROM WORK.FILTER_FOR_FINALFINAL_SAS7B_0000 T1
	  GROUP BY T1.STATE
ORDER BY T1.STATE;
QUIT;

GOPTIONS RESET=ALL BORDER;		/* OPTIONS FOF BUILDING BLOCKMAP       */
TITLE1 "NUMBER OF SIGHTINGS AND TEMPERATURE";
LEGEND1 LABEL=(POSITION=TOP) SHAPE=BAR(.3IN,.1IN);
FOOTNOTE1 J=R "THIS MAP DRAWN WITH GFK MAP DATA";
PATTERN1 VALUE=MSOLID COLOR=TAN;
					/* PROC GMAP TO CREATE BLOCK MAPS ON MAP*/
PROC GMAP DATA=WORK.FILTER_FOR_FINALFINAL_SAS7BDAT  MAP=MAPS.US ALL;
ID STATE;
CHORO NUMOFSIGHTINGS MAXTEMP MINTEMP/ DISCRETE LEGEND=LEGEND1 COUTLINE=GRAY98 ANNOTATE=LABELOUT;
BLOCK NUMOFSIGHTINGS MAXTEMP MINTEMP / BLOCKSIZE=2 RELZERO;
RUN;
